==> haskell-logict-0.6.0.2-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-logict.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: logict
version: 0.6.0.2
id: logict-0.6.0.2-LloWd77HrlqnDbOXNX0oI
key: logict-0.6.0.2-LloWd77HrlqnDbOXNX0oI
license: BSD3
copyright: Copyright (c) 2007-2014, Dan Doel,
           Copyright (c) 2011-2013, Edward Kmett,
           Copyright (c) 2014, Roman Cheplyaka
maintainer: dan.doel@gmail.com
homepage: http://code.haskell.org/~dolio/
synopsis: A backtracking logic-programming monad.
description:
    A continuation-based, backtracking, logic programming monad.
    An adaptation of the two-continuation implementation found
    in the paper "Backtracking, Interleaving, and Terminating
    Monad Transformers" available here:
    <http://okmij.org/ftp/papers/LogicT.pdf>
category: Control
author: Dan Doel
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Logic Control.Monad.Logic.Class
abi: 5e492f45ccd4257244a2334ea5e99e1e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/logict-0.6.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/logict-0.6.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/logict-0.6.0.2
hs-libraries: HSlogict-0.6.0.2-LloWd77HrlqnDbOXNX0oI
depends:
    base-4.10.1.0 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
haddock-interfaces: /usr/share/doc/haskell-logict/html/logict.haddock
haddock-html: /usr/share/doc/haskell-logict/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-logict-0.6.0.2-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-logict.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: logict
version: 0.6.0.2
id: logict-0.6.0.2-5lxUMo7vnTpCrEyOKX3WTG
key: logict-0.6.0.2-5lxUMo7vnTpCrEyOKX3WTG
license: BSD3
copyright: Copyright (c) 2007-2014, Dan Doel,
           Copyright (c) 2011-2013, Edward Kmett,
           Copyright (c) 2014, Roman Cheplyaka
maintainer: dan.doel@gmail.com
homepage: http://code.haskell.org/~dolio/
synopsis: A backtracking logic-programming monad.
description:
    A continuation-based, backtracking, logic programming monad.
    An adaptation of the two-continuation implementation found
    in the paper "Backtracking, Interleaving, and Terminating
    Monad Transformers" available here:
    <http://okmij.org/ftp/papers/LogicT.pdf>
category: Control
author: Dan Doel
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Logic Control.Monad.Logic.Class
abi: 2bdd4dbee8f5a57679e191f0b832f9a6
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/logict-0.6.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/logict-0.6.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/logict-0.6.0.2
hs-libraries: HSlogict-0.6.0.2-5lxUMo7vnTpCrEyOKX3WTG
depends:
    base-4.10.1.0 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
haddock-interfaces: /usr/share/doc/haskell-logict/html/logict.haddock
haddock-html: /usr/share/doc/haskell-logict/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
